// Copyright (C) 2014-2020  CEA/DEN, EDF R&D, OPEN CASCADE
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
//
// See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
//

// internal includes
#include "STLPlugin_IECallBack.hxx"
#include "STLPlugin_IOperations.hxx"
#include "STLPlugin_OperationsCreator.hxx"

//=============================================================================
/*!
 *  constructor
 */
//=============================================================================
STLPlugin_IECallBack::STLPlugin_IECallBack()
{
}

//=============================================================================
/*!
 *  destructor
 */
//=============================================================================
STLPlugin_IECallBack::~STLPlugin_IECallBack()
{
}

//=============================================================================
/*!
 *  Export
 */
//=============================================================================
bool 
STLPlugin_IECallBack::Export( const Handle(GEOM_Object)      theOriginal,
                              const TCollection_AsciiString& theFileName,
                              const TCollection_AsciiString& theFormatName )
{
  STLPlugin_IOperations* aPluginOperations = STLPlugin_OperationsCreator::get( GetEngine() );
  bool anIsASCII = ( theFormatName == "STL_Bin") ? false : true;
  const double aDeflection = 0.001;
  const bool anIsRelative = true;
  aPluginOperations->ExportSTL( theOriginal, theFileName, anIsASCII, aDeflection, anIsRelative );
  return true;
}

//=============================================================================
/*!
 *  Import
 */
//=============================================================================
Handle(TColStd_HSequenceOfTransient)
STLPlugin_IECallBack::Import( const TCollection_AsciiString& /*theFormatName*/,
                              const TCollection_AsciiString& theFileName )
{
  STLPlugin_IOperations* aPluginOperations = STLPlugin_OperationsCreator::get( GetEngine() );
  return aPluginOperations->ImportSTL( theFileName );
}

